@@ -66,7 +66,7 @@ class GitDownloaderTest extends TestCase
             $config = new Config();
         }
         if (!$config->has('home')) {
-            $tmpDir = realpath(sys_get_temp_dir()).DIRECTORY_SEPARATOR.'cmptest-'.md5(uniqid('', true));
+            $tmpDir = realpath(sys_get_temp_dir()).DIRECTORY_SEPARATOR.'cmptest-'.bin2hex(random_bytes(5));
             $config->merge(['config' => ['home' => $tmpDir]]);
         }
 
